import codepipeline = require('@aws-cdk/aws-codepipeline-api');
import cdk = require('@aws-cdk/cdk');
import { IRepository } from './repository';
/**
 * Common properties for creating {@link PipelineSourceAction} -
 * either directly, through its constructor,
 * or through {@link IRepository#toCodePipelineSourceAction}.
 */
export interface CommonPipelineSourceActionProps extends codepipeline.CommonActionProps {
    /**
     * The name of the source's output artifact.
     * CfnOutput artifacts are used by CodePipeline as inputs into other actions.
     *
     * @default a name will be auto-generated
     */
    readonly outputArtifactName?: string;
    /**
     * @default 'master'
     */
    readonly branch?: string;
    /**
     * Whether AWS CodePipeline should poll for source changes.
     * If this is `false`, the Pipeline will use CloudWatch Events to detect source changes instead.
     *
     * @default false
     */
    readonly pollForSourceChanges?: boolean;
}
/**
 * Construction properties of the {@link PipelineSourceAction CodeCommit source CodePipeline Action}.
 */
export interface PipelineSourceActionProps extends CommonPipelineSourceActionProps {
    /**
     * The CodeCommit repository.
     */
    readonly repository: IRepository;
}
/**
 * CodePipeline Source that is provided by an AWS CodeCommit repository.
 */
export declare class PipelineSourceAction extends codepipeline.SourceAction {
    private readonly props;
    constructor(props: PipelineSourceActionProps);
    protected bind(stage: codepipeline.IStage, _scope: cdk.Construct): void;
}
